#
# spec file for package python-django-cors-headers
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-django-cors-headers
Version:        4.5.0
Release:        1.1
Summary:        A Django App that adds CORS headers to responses
License:        MIT
URL:            https://github.com/adamchainz/django-cors-headers
Source:         https://github.com/adamchainz/django-cors-headers/archive/refs/tags/%{version}.tar.gz#/django-cors-headers-%{version}.tar.gz
BuildRequires:  %{python_module Django}
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest-django}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django
BuildArch:      noarch
%python_subpackages

%description
A Django App that adds CORS (Cross-Origin Resource Sharing) headers to
responses.

%prep
%setup -q -n django-cors-headers-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export PYTHONPATH=$PWD
export DJANGO_SETTINGS_MODULE=tests.settings
%pytest

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/corsheaders/
%{python_sitelib}/django[-_]cors[-_]headers*/

%changelog
* Mon Oct 28 2024 Dirk Müller <dmueller@suse.com>
- update to 4.5.0:
  * Drop Python 3.8 support.
  * Support Python 3.13.
* Sat Jun 29 2024 Dirk Müller <dmueller@suse.com>
- update to 4.4.0:
  * Support Django 5.1.
  * Fixed ASGI compatibility on Python 3.12. Thanks to Adrian
    Capitanu for the report in Issue #908 and Rooyal in PR #911.
  * Avoid adding the access-control-allow-credentials header to
    unallowed responses.
  * Drop Python 3.7 support.
  * Support Python 3.12.
  * Add CORS_ALLOW_PRIVATE_NETWORK setting, which enables support
    for the Local Network Access draft specification. Thanks to
    Issac Kelly in PR #745 and jjurgens0 in PR #833.
  * Switch from urlparse() to urlsplit() for URL parsing,
    reducing the middleware runtime up to 5%%. This changes the
    type passed to origin_found_in_white_lists(), so if you have
    subclassed the middleware to override this method, you should
    check it is compatible (it most likely is). Thanks to Thibaut
    Decombe in PR #793.
* Thu Mar 21 2024 Max Lin <mlin@suse.com>
- Add %%{?sle15_python_module_pythons}
* Tue Oct 11 2022 John Vandenberg <jayvdb@gmail.com>
- Update to v3.13.0
  * Support Python 3.11.
  * Support Django 4.1.
- from v3.12.0 (2022-05-10)
  * Drop support for Django 2.2, 3.0, and 3.1.
- from v3.11.0 (2022-01-10)
  * Drop Python 3.6 support.
- from v3.10.1 (2021-12-05)
  * Prevent a crash when an invalid Origin header is sent.
- from v3.10.0 (2021-10-05)
  * Support Python 3.10.
- from v3.9.0 (2021-09-28)
  * Support Django 4.0.
- from v3.8.0 (2021-08-15)
  * Add type hints.
  * Stop distributing tests to reduce package size
* Fri Jan  7 2022 John Vandenberg <jayvdb@gmail.com>
- Skip Tumbleweed Python 3.6 incompatible with Django 4
* Sun May  9 2021 Daniel Molkentin <daniel.molkentin@suse.com>
- Update to 3.7.0
  * Support Django 3.2.
  * Drop Python 3.5 support.
  * Support Python 3.9.
  * Following Django’s example in Ticket #31670 for replacing the
    term “whitelist”, plus an aim to make the setting names more
    comprehensible, the following settings have been renamed:
  * CORS_ORIGIN_WHITELIST -> CORS_ALLOWED_ORIGINS
  * CORS_ORIGIN_REGEX_WHITELIST -> CORS_ALLOWED_ORIGIN_REGEXES
  * CORS_ORIGIN_ALLOW_ALL -> CORS_ALLOW_ALL_ORIGINS
    The old names will continue to work as aliases, with the new
    ones taking precedence.
* Wed Jul  1 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 3.4.0
  * Add Django 3.1 support.
* Tue Jun  9 2020 Ondřej Súkup <mimi.vx@gmail.com>
- Update to 3.3.0
  * Drop Django 1.11 support. Only Django 2.0+ is supported now.
  * Drop the providing_args argument from Signal to prevent
    a deprecation warning on Django 3.1.
* Mon Jan 13 2020 Tomáš Chvátal <tchvatal@suse.com>
- Build on Leap by not using the macros
* Tue Jan  7 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.2.1:
  * Converted setuptools metadata to configuration file.
  * Support Python 3.8.
* Mon Oct  7 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.1.1:
  * Support the value file:// for origins, which is accidentally
    sent by some versions of Chrome on Android.
* Mon Sep 16 2019 ecsos@opensuse.org
- Fix build error for Leap.
* Mon Sep 16 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.1.0:
  * Drop Python 2 support, only Python 3.5-3.7 is supported now.
  * Fix all links for move from github.com/ottoyiu/django-cors-headers to
    github.com/adamchainz/django-cors-headers.
  * Add a hint to the corsheaders.E013 check to make it more obvious how to resolve it.
  * Allow 'null' in CORS_ORIGIN_WHITELIST check.
  * CORS_ORIGIN_WHITELIST now requires URI schemes, and optionally ports
  * Removed the CORS_MODEL setting, and associated class
* Mon May  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.5.3:
  * Tested on Django 2.2. No changes were needed for compatibility.
  * Tested on Python 3.7. No changes were needed for compatibility.
* Tue Mar 19 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.5.2:
  * Improve inclusion of tests in sdist to ignore .pyc files.
* Fri Mar 15 2019 John Vandenberg <jayvdb@gmail.com>
- Use PyPI sdist
- Update to v2.5.1
  * Include test infrastructure in sdist
* Sun Mar 10 2019 John Vandenberg <jayvdb@gmail.com>
- Remove %%bcond and add %%check, with 100%% coverage
- Update to v2.5.0
  * Drop Django 1.8, 1.9, and 1.10 support. Django 1.11+ is supported.
- from v2.4.1
  * Fix DeprecationWarning from importing collections.abc.Sequence
    on Python 3.7.
* Tue Feb 26 2019 John Vandenberg <jayvdb@gmail.com>
- Add Django dependency
- Use %%license
- Update to v2.4.0
  * Always add 'Origin' to the 'Vary' header for responses to enabled
    URL's, to prevent caching of responses intended for one origin
    being served for another.
- from v2.3.0
  * Match ``CORS_URLS_REGEX`` to ``request.path_info`` instead of
    ``request.path``, so the patterns can work without knowing the
    site's path prefix at configuration time.
- from v2.2.1
  * Add ``Content-Length`` header to CORS preflight requests.
    This fixes issues with some HTTP proxies and servers,
    e.g. AWS Elastic Beanstalk.
- from v2.2.0
  * Django 2.0 compatibility. Again there were no changes to the
    actual library code, so previous versions probably work.
  * Ensured that ``request._cors_enabled`` is always a ``bool()`` -
    previously it could be set to a regex match object.
* Tue Aug  8 2017 mardnh@gmx.de
- Initial package, version 2.1.0
